// Type definitions for non-npm package Drive API v3 3.0
// Project: https://developers.google.com/drive/
// Definitions by: Maxim Mazurok <https://github.com/Maxim-Mazurok>
//                 Google API Typings Generator <https://github.com/google-api-typings-generator>
//                 Nick Amoscato <https://github.com/namoscato>
//                 Declan Vong <https://github.com/declanvong>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.8

// IMPORTANT
// This file was generated by https://github.com/Maxim-Mazurok/google-api-typings-generator. Please do not edit it manually.
// In case of any problems please post issue to https://github.com/Maxim-Mazurok/google-api-typings-generator
// Generated from: https://www.googleapis.com/discovery/v1/apis/drive/v3/rest
// Revision: 20201012

/// <reference types="gapi.client" />

declare namespace gapi.client {
    /** Load Drive API v3 */
    function load(name: "drive", version: "v3"): PromiseLike<void>;
    function load(name: "drive", version: "v3", callback: () => any): void;

    namespace drive {
        interface About {
            /** Whether the user has installed the requesting app. */
            appInstalled?: boolean;
            /** Whether the user can create shared drives. */
            canCreateDrives?: boolean;
            /** Deprecated - use canCreateDrives instead. */
            canCreateTeamDrives?: boolean;
            /** A list of themes that are supported for shared drives. */
            driveThemes?: Array<{
                /** A link to this theme's background image. */
                backgroundImageLink?: string;
                /** The color of this theme as an RGB hex string. */
                colorRgb?: string;
                /** The ID of the theme. */
                id?: string;
            }>;
            /** A map of source MIME type to possible targets for all supported exports. */
            exportFormats?: { [P in string]: string[] };
            /** The currently supported folder colors as RGB hex strings. */
            folderColorPalette?: string[];
            /** A map of source MIME type to possible targets for all supported imports. */
            importFormats?: { [P in string]: string[] };
            /** Identifies what kind of resource this is. Value: the fixed string "drive#about". */
            kind?: string;
            /** A map of maximum import sizes by MIME type, in bytes. */
            maxImportSizes?: { [P in string]: string };
            /** The maximum upload size in bytes. */
            maxUploadSize?: string;
            /** The user's storage quota limits and usage. All fields are measured in bytes. */
            storageQuota?: {
                /** The usage limit, if applicable. This will not be present if the user has unlimited storage. */
                limit?: string;
                /** The total usage across all services. */
                usage?: string;
                /** The usage by all files in Google Drive. */
                usageInDrive?: string;
                /** The usage by trashed files in Google Drive. */
                usageInDriveTrash?: string;
            };
            /** Deprecated - use driveThemes instead. */
            teamDriveThemes?: Array<{
                /** Deprecated - use driveThemes/backgroundImageLink instead. */
                backgroundImageLink?: string;
                /** Deprecated - use driveThemes/colorRgb instead. */
                colorRgb?: string;
                /** Deprecated - use driveThemes/id instead. */
                id?: string;
            }>;
            /** The authenticated user. */
            user?: User;
        }
        interface Change {
            /** The type of the change. Possible values are file and drive. */
            changeType?: string;
            /** The updated state of the shared drive. Present if the changeType is drive, the user is still a member of the shared drive, and the shared drive has not been deleted. */
            drive?: Drive;
            /** The ID of the shared drive associated with this change. */
            driveId?: string;
            /** The updated state of the file. Present if the type is file and the file has not been removed from this list of changes. */
            file?: File;
            /** The ID of the file which has changed. */
            fileId?: string;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#change". */
            kind?: string;
            /** Whether the file or shared drive has been removed from this list of changes, for example by deletion or loss of access. */
            removed?: boolean;
            /** Deprecated - use drive instead. */
            teamDrive?: TeamDrive;
            /** Deprecated - use driveId instead. */
            teamDriveId?: string;
            /** The time of this change (RFC 3339 date-time). */
            time?: string;
            /** Deprecated - use changeType instead. */
            type?: string;
        }
        interface ChangeList {
            /** The list of changes. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            changes?: Change[];
            /** Identifies what kind of resource this is. Value: the fixed string "drive#changeList". */
            kind?: string;
            /** The starting page token for future changes. This will be present only if the end of the current changes list has been reached. */
            newStartPageToken?: string;
            /**
             * The page token for the next page of changes. This will be absent if the end of the changes list has been reached. If the token is rejected for any reason, it should be discarded,
             * and pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
        }
        interface Channel {
            /** The address where notifications are delivered for this channel. */
            address?: string;
            /** Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional. */
            expiration?: string;
            /** A UUID or similar unique string that identifies this channel. */
            id?: string;
            /** Identifies this as a notification channel used to watch for changes to a resource, which is "api#channel". */
            kind?: string;
            /** Additional parameters controlling delivery channel behavior. Optional. */
            params?: { [P in string]: string };
            /** A Boolean value to indicate whether payload is wanted. Optional. */
            payload?: boolean;
            /** An opaque ID that identifies the resource being watched on this channel. Stable across different API versions. */
            resourceId?: string;
            /** A version-specific identifier for the watched resource. */
            resourceUri?: string;
            /** An arbitrary string delivered to the target address with each notification delivered over this channel. Optional. */
            token?: string;
            /** The type of delivery mechanism used for this channel. */
            type?: string;
        }
        interface Comment {
            /** A region of the document represented as a JSON string. See anchor documentation for details on how to define and interpret anchor properties. */
            anchor?: string;
            /** The author of the comment. The author's email address and permission ID will not be populated. */
            author?: User;
            /** The plain text content of the comment. This field is used for setting the content, while htmlContent should be displayed. */
            content?: string;
            /** The time at which the comment was created (RFC 3339 date-time). */
            createdTime?: string;
            /** Whether the comment has been deleted. A deleted comment has no content. */
            deleted?: boolean;
            /** The content of the comment with HTML formatting. */
            htmlContent?: string;
            /** The ID of the comment. */
            id?: string;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#comment". */
            kind?: string;
            /** The last time the comment or any of its replies was modified (RFC 3339 date-time). */
            modifiedTime?: string;
            /** The file content to which the comment refers, typically within the anchor region. For a text file, for example, this would be the text at the location of the comment. */
            quotedFileContent?: {
                /** The MIME type of the quoted content. */
                mimeType?: string;
                /** The quoted content itself. This is interpreted as plain text if set through the API. */
                value?: string;
            };
            /** The full list of replies to the comment in chronological order. */
            replies?: Reply[];
            /** Whether the comment has been resolved by one of its replies. */
            resolved?: boolean;
        }
        interface CommentList {
            /** The list of comments. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            comments?: Comment[];
            /** Identifies what kind of resource this is. Value: the fixed string "drive#commentList". */
            kind?: string;
            /**
             * The page token for the next page of comments. This will be absent if the end of the comments list has been reached. If the token is rejected for any reason, it should be discarded,
             * and pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
        }
        interface ContentRestriction {
            /**
             * Whether the content of the file is read-only. If a file is read-only, a new revision of the file may not be added, comments may not be added or modified, and the title of the file
             * may not be modified.
             */
            readOnly?: boolean;
            /** Reason for why the content of the file is restricted. This is only mutable on requests that also set readOnly=true. */
            reason?: string;
            /** The user who set the content restriction. Only populated if readOnly is true. */
            restrictingUser?: User;
            /** The time at which the content restriction was set (formatted RFC 3339 timestamp). Only populated if readOnly is true. */
            restrictionTime?: string;
            /** The type of the content restriction. Currently the only possible value is globalContentRestriction. */
            type?: string;
        }
        interface Drive {
            /**
             * An image file and cropping parameters from which a background image for this shared drive is set. This is a write only field; it can only be set on drive.drives.update requests that
             * don't set themeId. When specified, all fields of the backgroundImageFile must be set.
             */
            backgroundImageFile?: {
                /** The ID of an image file in Google Drive to use for the background image. */
                id?: string;
                /**
                 * The width of the cropped image in the closed range of 0 to 1. This value represents the width of the cropped image divided by the width of the entire image. The height is
                 * computed by applying a width to height aspect ratio of 80 to 9. The resulting image must be at least 1280 pixels wide and 144 pixels high.
                 */
                width?: number;
                /**
                 * The X coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the horizontal
                 * distance from the left side of the entire image to the left side of the cropping area divided by the width of the entire image.
                 */
                xCoordinate?: number;
                /**
                 * The Y coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the vertical
                 * distance from the top side of the entire image to the top side of the cropping area divided by the height of the entire image.
                 */
                yCoordinate?: number;
            };
            /** A short-lived link to this shared drive's background image. */
            backgroundImageLink?: string;
            /** Capabilities the current user has on this shared drive. */
            capabilities?: {
                /** Whether the current user can add children to folders in this shared drive. */
                canAddChildren?: boolean;
                /** Whether the current user can change the copyRequiresWriterPermission restriction of this shared drive. */
                canChangeCopyRequiresWriterPermissionRestriction?: boolean;
                /** Whether the current user can change the domainUsersOnly restriction of this shared drive. */
                canChangeDomainUsersOnlyRestriction?: boolean;
                /** Whether the current user can change the background of this shared drive. */
                canChangeDriveBackground?: boolean;
                /** Whether the current user can change the driveMembersOnly restriction of this shared drive. */
                canChangeDriveMembersOnlyRestriction?: boolean;
                /** Whether the current user can comment on files in this shared drive. */
                canComment?: boolean;
                /** Whether the current user can copy files in this shared drive. */
                canCopy?: boolean;
                /** Whether the current user can delete children from folders in this shared drive. */
                canDeleteChildren?: boolean;
                /** Whether the current user can delete this shared drive. Attempting to delete the shared drive may still fail if there are untrashed items inside the shared drive. */
                canDeleteDrive?: boolean;
                /** Whether the current user can download files in this shared drive. */
                canDownload?: boolean;
                /** Whether the current user can edit files in this shared drive */
                canEdit?: boolean;
                /** Whether the current user can list the children of folders in this shared drive. */
                canListChildren?: boolean;
                /** Whether the current user can add members to this shared drive or remove them or change their role. */
                canManageMembers?: boolean;
                /** Whether the current user can read the revisions resource of files in this shared drive. */
                canReadRevisions?: boolean;
                /** Whether the current user can rename files or folders in this shared drive. */
                canRename?: boolean;
                /** Whether the current user can rename this shared drive. */
                canRenameDrive?: boolean;
                /** Whether the current user can share files or folders in this shared drive. */
                canShare?: boolean;
                /** Whether the current user can trash children from folders in this shared drive. */
                canTrashChildren?: boolean;
            };
            /** The color of this shared drive as an RGB hex string. It can only be set on a drive.drives.update request that does not set themeId. */
            colorRgb?: string;
            /** The time at which the shared drive was created (RFC 3339 date-time). */
            createdTime?: string;
            /** Whether the shared drive is hidden from default view. */
            hidden?: boolean;
            /** The ID of this shared drive which is also the ID of the top level folder of this shared drive. */
            id?: string;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#drive". */
            kind?: string;
            /** The name of this shared drive. */
            name?: string;
            /** A set of restrictions that apply to this shared drive or items inside this shared drive. */
            restrictions?: {
                /** Whether administrative privileges on this shared drive are required to modify restrictions. */
                adminManagedRestrictions?: boolean;
                /**
                 * Whether the options to copy, print, or download files inside this shared drive, should be disabled for readers and commenters. When this restriction is set to true, it will
                 * override the similarly named field to true for any file inside this shared drive.
                 */
                copyRequiresWriterPermission?: boolean;
                /**
                 * Whether access to this shared drive and items inside this shared drive is restricted to users of the domain to which this shared drive belongs. This restriction may be
                 * overridden by other sharing policies controlled outside of this shared drive.
                 */
                domainUsersOnly?: boolean;
                /** Whether access to items inside this shared drive is restricted to its members. */
                driveMembersOnly?: boolean;
            };
            /**
             * The ID of the theme from which the background image and color will be set. The set of possible driveThemes can be retrieved from a drive.about.get response. When not specified on a
             * drive.drives.create request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that don't set
             * colorRgb or backgroundImageFile.
             */
            themeId?: string;
        }
        interface DriveList {
            /** The list of shared drives. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            drives?: Drive[];
            /** Identifies what kind of resource this is. Value: the fixed string "drive#driveList". */
            kind?: string;
            /**
             * The page token for the next page of shared drives. This will be absent if the end of the list has been reached. If the token is rejected for any reason, it should be discarded, and
             * pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
        }
        interface File {
            /**
             * A collection of arbitrary key-value pairs which are private to the requesting app.
             * Entries with null values are cleared in update and copy requests.
             */
            appProperties?: { [P in string]: string };
            /** Capabilities the current user has on this file. Each capability corresponds to a fine-grained action that a user may take. */
            capabilities?: {
                /** Whether the current user can add children to this folder. This is always false when the item is not a folder. */
                canAddChildren?: boolean;
                /**
                 * Whether the current user can add a folder from another drive (different shared drive or My Drive) to this folder. This is false when the item is not a folder. Only populated for
                 * items in shared drives.
                 */
                canAddFolderFromAnotherDrive?: boolean;
                /** Whether the current user can add a parent for the item without removing an existing parent in the same request. Not populated for shared drive files. */
                canAddMyDriveParent?: boolean;
                /** Whether the current user can change the copyRequiresWriterPermission restriction of this file. */
                canChangeCopyRequiresWriterPermission?: boolean;
                /** Deprecated */
                canChangeViewersCanCopyContent?: boolean;
                /** Whether the current user can comment on this file. */
                canComment?: boolean;
                /**
                 * Whether the current user can copy this file. For an item in a shared drive, whether the current user can copy non-folder descendants of this item, or this item itself if it is
                 * not a folder.
                 */
                canCopy?: boolean;
                /** Whether the current user can delete this file. */
                canDelete?: boolean;
                /** Whether the current user can delete children of this folder. This is false when the item is not a folder. Only populated for items in shared drives. */
                canDeleteChildren?: boolean;
                /** Whether the current user can download this file. */
                canDownload?: boolean;
                /**
                 * Whether the current user can edit this file. Other factors may limit the type of changes a user can make to a file. For example, see canChangeCopyRequiresWriterPermission or
                 * canModifyContent.
                 */
                canEdit?: boolean;
                /** Whether the current user can list the children of this folder. This is always false when the item is not a folder. */
                canListChildren?: boolean;
                /** Whether the current user can modify the content of this file. */
                canModifyContent?: boolean;
                /** Whether the current user can modify restrictions on content of this file. */
                canModifyContentRestriction?: boolean;
                /** Whether the current user can move children of this folder outside of the shared drive. This is false when the item is not a folder. Only populated for items in shared drives. */
                canMoveChildrenOutOfDrive?: boolean;
                /** Deprecated - use canMoveChildrenOutOfDrive instead. */
                canMoveChildrenOutOfTeamDrive?: boolean;
                /**
                 * Whether the current user can move children of this folder within this drive. This is false when the item is not a folder. Note that a request to move the child may still fail
                 * depending on the current user's access to the child and to the destination folder.
                 */
                canMoveChildrenWithinDrive?: boolean;
                /** Deprecated - use canMoveChildrenWithinDrive instead. */
                canMoveChildrenWithinTeamDrive?: boolean;
                /** Deprecated - use canMoveItemOutOfDrive instead. */
                canMoveItemIntoTeamDrive?: boolean;
                /**
                 * Whether the current user can move this item outside of this drive by changing its parent. Note that a request to change the parent of the item may still fail depending on the
                 * new parent that is being added.
                 */
                canMoveItemOutOfDrive?: boolean;
                /** Deprecated - use canMoveItemOutOfDrive instead. */
                canMoveItemOutOfTeamDrive?: boolean;
                /**
                 * Whether the current user can move this item within this drive. Note that a request to change the parent of the item may still fail depending on the new parent that is being
                 * added and the parent that is being removed.
                 */
                canMoveItemWithinDrive?: boolean;
                /** Deprecated - use canMoveItemWithinDrive instead. */
                canMoveItemWithinTeamDrive?: boolean;
                /** Deprecated - use canMoveItemWithinDrive or canMoveItemOutOfDrive instead. */
                canMoveTeamDriveItem?: boolean;
                /** Whether the current user can read the shared drive to which this file belongs. Only populated for items in shared drives. */
                canReadDrive?: boolean;
                /**
                 * Whether the current user can read the revisions resource of this file. For a shared drive item, whether revisions of non-folder descendants of this item, or this item itself if
                 * it is not a folder, can be read.
                 */
                canReadRevisions?: boolean;
                /** Deprecated - use canReadDrive instead. */
                canReadTeamDrive?: boolean;
                /**
                 * Whether the current user can remove children from this folder. This is always false when the item is not a folder. For a folder in a shared drive, use canDeleteChildren or
                 * canTrashChildren instead.
                 */
                canRemoveChildren?: boolean;
                /** Whether the current user can remove a parent from the item without adding another parent in the same request. Not populated for shared drive files. */
                canRemoveMyDriveParent?: boolean;
                /** Whether the current user can rename this file. */
                canRename?: boolean;
                /** Whether the current user can modify the sharing settings for this file. */
                canShare?: boolean;
                /** Whether the current user can move this file to trash. */
                canTrash?: boolean;
                /** Whether the current user can trash children of this folder. This is false when the item is not a folder. Only populated for items in shared drives. */
                canTrashChildren?: boolean;
                /** Whether the current user can restore this file from trash. */
                canUntrash?: boolean;
            };
            /** Additional information about the content of the file. These fields are never populated in responses. */
            contentHints?: {
                /** Text to be indexed for the file to improve fullText queries. This is limited to 128KB in length and may contain HTML elements. */
                indexableText?: string;
                /** A thumbnail for the file. This will only be used if Google Drive cannot generate a standard thumbnail. */
                thumbnail?: {
                    /** The thumbnail data encoded with URL-safe Base64 (RFC 4648 section 5). */
                    image?: string;
                    /** The MIME type of the thumbnail. */
                    mimeType?: string;
                };
            };
            /** Restrictions for accessing the content of the file. Only populated if such a restriction exists. */
            contentRestrictions?: ContentRestriction[];
            /** Whether the options to copy, print, or download this file, should be disabled for readers and commenters. */
            copyRequiresWriterPermission?: boolean;
            /** The time at which the file was created (RFC 3339 date-time). */
            createdTime?: string;
            /** A short description of the file. */
            description?: string;
            /** ID of the shared drive the file resides in. Only populated for items in shared drives. */
            driveId?: string;
            /** Whether the file has been explicitly trashed, as opposed to recursively trashed from a parent folder. */
            explicitlyTrashed?: boolean;
            /** Links for exporting Google Docs to specific formats. */
            exportLinks?: { [P in string]: string };
            /** The final component of fullFileExtension. This is only available for files with binary content in Google Drive. */
            fileExtension?: string;
            /**
             * The color for a folder as an RGB hex string. The supported colors are published in the folderColorPalette field of the About resource.
             * If an unsupported color is specified, the closest color in the palette will be used instead.
             */
            folderColorRgb?: string;
            /**
             * The full file extension extracted from the name field. May contain multiple concatenated extensions, such as "tar.gz". This is only available for files with binary content in Google
             * Drive.
             * This is automatically updated when the name field changes, however it is not cleared if the new name does not contain a valid extension.
             */
            fullFileExtension?: string;
            /** Whether there are permissions directly on this file. This field is only populated for items in shared drives. */
            hasAugmentedPermissions?: boolean;
            /** Whether this file has a thumbnail. This does not indicate whether the requesting app has access to the thumbnail. To check access, look for the presence of the thumbnailLink field. */
            hasThumbnail?: boolean;
            /** The ID of the file's head revision. This is currently only available for files with binary content in Google Drive. */
            headRevisionId?: string;
            /** A static, unauthenticated link to the file's icon. */
            iconLink?: string;
            /** The ID of the file. */
            id?: string;
            /** Additional metadata about image media, if available. */
            imageMediaMetadata?: {
                /** The aperture used to create the photo (f-number). */
                aperture?: number;
                /** The make of the camera used to create the photo. */
                cameraMake?: string;
                /** The model of the camera used to create the photo. */
                cameraModel?: string;
                /** The color space of the photo. */
                colorSpace?: string;
                /** The exposure bias of the photo (APEX value). */
                exposureBias?: number;
                /** The exposure mode used to create the photo. */
                exposureMode?: string;
                /** The length of the exposure, in seconds. */
                exposureTime?: number;
                /** Whether a flash was used to create the photo. */
                flashUsed?: boolean;
                /** The focal length used to create the photo, in millimeters. */
                focalLength?: number;
                /** The height of the image in pixels. */
                height?: number;
                /** The ISO speed used to create the photo. */
                isoSpeed?: number;
                /** The lens used to create the photo. */
                lens?: string;
                /** Geographic location information stored in the image. */
                location?: {
                    /** The altitude stored in the image. */
                    altitude?: number;
                    /** The latitude stored in the image. */
                    latitude?: number;
                    /** The longitude stored in the image. */
                    longitude?: number;
                };
                /** The smallest f-number of the lens at the focal length used to create the photo (APEX value). */
                maxApertureValue?: number;
                /** The metering mode used to create the photo. */
                meteringMode?: string;
                /** The number of clockwise 90 degree rotations applied from the image's original orientation. */
                rotation?: number;
                /** The type of sensor used to create the photo. */
                sensor?: string;
                /** The distance to the subject of the photo, in meters. */
                subjectDistance?: number;
                /** The date and time the photo was taken (EXIF DateTime). */
                time?: string;
                /** The white balance mode used to create the photo. */
                whiteBalance?: string;
                /** The width of the image in pixels. */
                width?: number;
            };
            /** Whether the file was created or opened by the requesting app. */
            isAppAuthorized?: boolean;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#file". */
            kind?: string;
            /** The last user to modify the file. */
            lastModifyingUser?: User;
            /** The MD5 checksum for the content of the file. This is only applicable to files with binary content in Google Drive. */
            md5Checksum?: string;
            /**
             * The MIME type of the file.
             * Google Drive will attempt to automatically detect an appropriate value from uploaded content if no value is provided. The value cannot be changed unless a new revision is uploaded.
             * If a file is created with a Google Doc MIME type, the uploaded content will be imported if possible. The supported import formats are published in the About resource.
             */
            mimeType?: string;
            /** Whether the file has been modified by this user. */
            modifiedByMe?: boolean;
            /** The last time the file was modified by the user (RFC 3339 date-time). */
            modifiedByMeTime?: string;
            /**
             * The last time the file was modified by anyone (RFC 3339 date-time).
             * Note that setting modifiedTime will also update modifiedByMeTime for the user.
             */
            modifiedTime?: string;
            /**
             * The name of the file. This is not necessarily unique within a folder. Note that for immutable items such as the top level folders of shared drives, My Drive root folder, and
             * Application Data folder the name is constant.
             */
            name?: string;
            /** The original filename of the uploaded content if available, or else the original value of the name field. This is only available for files with binary content in Google Drive. */
            originalFilename?: string;
            /** Whether the user owns the file. Not populated for items in shared drives. */
            ownedByMe?: boolean;
            /** The owners of the file. Currently, only certain legacy files may have more than one owner. Not populated for items in shared drives. */
            owners?: User[];
            /**
             * The IDs of the parent folders which contain the file.
             * If not specified as part of a create request, the file will be placed directly in the user's My Drive folder. If not specified as part of a copy request, the file will inherit any
             * discoverable parents of the source file. Update requests must use the addParents and removeParents parameters to modify the parents list.
             */
            parents?: string[];
            /** List of permission IDs for users with access to this file. */
            permissionIds?: string[];
            /** The full list of permissions for the file. This is only available if the requesting user can share the file. Not populated for items in shared drives. */
            permissions?: Permission[];
            /**
             * A collection of arbitrary key-value pairs which are visible to all apps.
             * Entries with null values are cleared in update and copy requests.
             */
            properties?: { [P in string]: string };
            /** The number of storage quota bytes used by the file. This includes the head revision as well as previous revisions with keepForever enabled. */
            quotaBytesUsed?: string;
            /** Whether the file has been shared. Not populated for items in shared drives. */
            shared?: boolean;
            /** The time at which the file was shared with the user, if applicable (RFC 3339 date-time). */
            sharedWithMeTime?: string;
            /** The user who shared the file with the requesting user, if applicable. */
            sharingUser?: User;
            /** Shortcut file details. Only populated for shortcut files, which have the mimeType field set to application/vnd.google-apps.shortcut. */
            shortcutDetails?: {
                /** The ID of the file that this shortcut points to. */
                targetId?: string;
                /** The MIME type of the file that this shortcut points to. The value of this field is a snapshot of the target's MIME type, captured when the shortcut is created. */
                targetMimeType?: string;
            };
            /** The size of the file's content in bytes. This is only applicable to files with binary content in Google Drive. */
            size?: string;
            /** The list of spaces which contain the file. The currently supported values are 'drive', 'appDataFolder' and 'photos'. */
            spaces?: string[];
            /** Whether the user has starred the file. */
            starred?: boolean;
            /** Deprecated - use driveId instead. */
            teamDriveId?: string;
            /**
             * A short-lived link to the file's thumbnail, if available. Typically lasts on the order of hours. Only populated when the requesting app can access the file's content. If the file
             * isn't shared publicly, the URL returned in Files.thumbnailLink must be fetched using a credentialed request.
             */
            thumbnailLink?: string;
            /** The thumbnail version for use in thumbnail cache invalidation. */
            thumbnailVersion?: string;
            /**
             * Whether the file has been trashed, either explicitly or from a trashed parent folder. Only the owner may trash a file. The trashed item is excluded from all files.list responses
             * returned for any user who does not own the file. However, all users with access to the file can see the trashed item metadata in an API response. All users with access can copy,
             * download, export, and share the file.
             */
            trashed?: boolean;
            /** The time that the item was trashed (RFC 3339 date-time). Only populated for items in shared drives. */
            trashedTime?: string;
            /** If the file has been explicitly trashed, the user who trashed it. Only populated for items in shared drives. */
            trashingUser?: User;
            /** A monotonically increasing version number for the file. This reflects every change made to the file on the server, even those not visible to the user. */
            version?: string;
            /** Additional metadata about video media. This may not be available immediately upon upload. */
            videoMediaMetadata?: {
                /** The duration of the video in milliseconds. */
                durationMillis?: string;
                /** The height of the video in pixels. */
                height?: number;
                /** The width of the video in pixels. */
                width?: number;
            };
            /** Whether the file has been viewed by this user. */
            viewedByMe?: boolean;
            /** The last time the file was viewed by the user (RFC 3339 date-time). */
            viewedByMeTime?: string;
            /** Deprecated - use copyRequiresWriterPermission instead. */
            viewersCanCopyContent?: boolean;
            /** A link for downloading the content of the file in a browser. This is only available for files with binary content in Google Drive. */
            webContentLink?: string;
            /** A link for opening the file in a relevant Google editor or viewer in a browser. */
            webViewLink?: string;
            /** Whether users with only writer permission can modify the file's permissions. Not populated for items in shared drives. */
            writersCanShare?: boolean;
        }
        interface FileList {
            /** The list of files. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            files?: File[];
            /**
             * Whether the search process was incomplete. If true, then some search results may be missing, since all documents were not searched. This may occur when searching multiple drives
             * with the "allDrives" corpora, but all corpora could not be searched. When this happens, it is suggested that clients narrow their query by choosing a different corpus such as "user"
             * or "drive".
             */
            incompleteSearch?: boolean;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#fileList". */
            kind?: string;
            /**
             * The page token for the next page of files. This will be absent if the end of the files list has been reached. If the token is rejected for any reason, it should be discarded, and
             * pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
        }
        interface GeneratedIds {
            /** The IDs generated for the requesting user in the specified space. */
            ids?: string[];
            /** Identifies what kind of resource this is. Value: the fixed string "drive#generatedIds". */
            kind?: string;
            /** The type of file that can be created with these IDs. */
            space?: string;
        }
        interface Permission {
            /** Whether the permission allows the file to be discovered through search. This is only applicable for permissions of type domain or anyone. */
            allowFileDiscovery?: boolean;
            /** Whether the account associated with this permission has been deleted. This field only pertains to user and group permissions. */
            deleted?: boolean;
            /**
             * The "pretty" name of the value of the permission. The following is a list of examples for each type of permission:
             * - user - User's full name, as defined for their Google account, such as "Joe Smith."
             * - group - Name of the Google Group, such as "The Company Administrators."
             * - domain - String domain name, such as "thecompany.com."
             * - anyone - No displayName is present.
             */
            displayName?: string;
            /** The domain to which this permission refers. */
            domain?: string;
            /** The email address of the user or group to which this permission refers. */
            emailAddress?: string;
            /**
             * The time at which this permission will expire (RFC 3339 date-time). Expiration times have the following restrictions:
             * - They can only be set on user and group permissions
             * - The time must be in the future
             * - The time cannot be more than a year in the future
             */
            expirationTime?: string;
            /** The ID of this permission. This is a unique identifier for the grantee, and is published in User resources as permissionId. IDs should be treated as opaque values. */
            id?: string;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#permission". */
            kind?: string;
            /** Details of whether the permissions on this shared drive item are inherited or directly on this item. This is an output-only field which is present only for shared drive items. */
            permissionDetails?: Array<{
                /** Whether this permission is inherited. This field is always populated. This is an output-only field. */
                inherited?: boolean;
                /** The ID of the item from which this permission is inherited. This is an output-only field. */
                inheritedFrom?: string;
                /**
                 * The permission type for this user. While new values may be added in future, the following are currently possible:
                 * - file
                 * - member
                 */
                permissionType?: string;
                /**
                 * The primary role for this user. While new values may be added in the future, the following are currently possible:
                 * - organizer
                 * - fileOrganizer
                 * - writer
                 * - commenter
                 * - reader
                 */
                role?: string;
            }>;
            /** A link to the user's profile photo, if available. */
            photoLink?: string;
            /**
             * The role granted by this permission. While new values may be supported in the future, the following are currently allowed:
             * - owner
             * - organizer
             * - fileOrganizer
             * - writer
             * - commenter
             * - reader
             */
            role?: string;
            /** Deprecated - use permissionDetails instead. */
            teamDrivePermissionDetails?: Array<{
                /** Deprecated - use permissionDetails/inherited instead. */
                inherited?: boolean;
                /** Deprecated - use permissionDetails/inheritedFrom instead. */
                inheritedFrom?: string;
                /** Deprecated - use permissionDetails/role instead. */
                role?: string;
                /** Deprecated - use permissionDetails/permissionType instead. */
                teamDrivePermissionType?: string;
            }>;
            /**
             * The type of the grantee. Valid values are:
             * - user
             * - group
             * - domain
             * - anyone  When creating a permission, if type is user or group, you must provide an emailAddress for the user or group. When type is domain, you must provide a domain. There isn't
             * extra information required for a anyone type.
             */
            type?: string;
            /** Indicates the view for this permission. Only populated for permissions that belong to a view. published is the only supported value. */
            view?: string;
        }
        interface PermissionList {
            /** Identifies what kind of resource this is. Value: the fixed string "drive#permissionList". */
            kind?: string;
            /**
             * The page token for the next page of permissions. This field will be absent if the end of the permissions list has been reached. If the token is rejected for any reason, it should be
             * discarded, and pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
            /** The list of permissions. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            permissions?: Permission[];
        }
        interface Reply {
            /**
             * The action the reply performed to the parent comment. Valid values are:
             * - resolve
             * - reopen
             */
            action?: string;
            /** The author of the reply. The author's email address and permission ID will not be populated. */
            author?: User;
            /** The plain text content of the reply. This field is used for setting the content, while htmlContent should be displayed. This is required on creates if no action is specified. */
            content?: string;
            /** The time at which the reply was created (RFC 3339 date-time). */
            createdTime?: string;
            /** Whether the reply has been deleted. A deleted reply has no content. */
            deleted?: boolean;
            /** The content of the reply with HTML formatting. */
            htmlContent?: string;
            /** The ID of the reply. */
            id?: string;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#reply". */
            kind?: string;
            /** The last time the reply was modified (RFC 3339 date-time). */
            modifiedTime?: string;
        }
        interface ReplyList {
            /** Identifies what kind of resource this is. Value: the fixed string "drive#replyList". */
            kind?: string;
            /**
             * The page token for the next page of replies. This will be absent if the end of the replies list has been reached. If the token is rejected for any reason, it should be discarded,
             * and pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
            /** The list of replies. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            replies?: Reply[];
        }
        interface Revision {
            /** Links for exporting Google Docs to specific formats. */
            exportLinks?: { [P in string]: string };
            /** The ID of the revision. */
            id?: string;
            /**
             * Whether to keep this revision forever, even if it is no longer the head revision. If not set, the revision will be automatically purged 30 days after newer content is uploaded. This
             * can be set on a maximum of 200 revisions for a file.
             * This field is only applicable to files with binary content in Drive.
             */
            keepForever?: boolean;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#revision". */
            kind?: string;
            /** The last user to modify this revision. */
            lastModifyingUser?: User;
            /** The MD5 checksum of the revision's content. This is only applicable to files with binary content in Drive. */
            md5Checksum?: string;
            /** The MIME type of the revision. */
            mimeType?: string;
            /** The last time the revision was modified (RFC 3339 date-time). */
            modifiedTime?: string;
            /** The original filename used to create this revision. This is only applicable to files with binary content in Drive. */
            originalFilename?: string;
            /** Whether subsequent revisions will be automatically republished. This is only applicable to Google Docs. */
            publishAuto?: boolean;
            /** Whether this revision is published. This is only applicable to Google Docs. */
            published?: boolean;
            /** A link to the published revision. This is only populated for Google Sites files. */
            publishedLink?: string;
            /** Whether this revision is published outside the domain. This is only applicable to Google Docs. */
            publishedOutsideDomain?: boolean;
            /** The size of the revision's content in bytes. This is only applicable to files with binary content in Drive. */
            size?: string;
        }
        interface RevisionList {
            /** Identifies what kind of resource this is. Value: the fixed string "drive#revisionList". */
            kind?: string;
            /**
             * The page token for the next page of revisions. This will be absent if the end of the revisions list has been reached. If the token is rejected for any reason, it should be
             * discarded, and pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
            /** The list of revisions. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            revisions?: Revision[];
        }
        interface StartPageToken {
            /** Identifies what kind of resource this is. Value: the fixed string "drive#startPageToken". */
            kind?: string;
            /** The starting page token for listing changes. */
            startPageToken?: string;
        }
        interface TeamDrive {
            /**
             * An image file and cropping parameters from which a background image for this Team Drive is set. This is a write only field; it can only be set on drive.teamdrives.update requests
             * that don't set themeId. When specified, all fields of the backgroundImageFile must be set.
             */
            backgroundImageFile?: {
                /** The ID of an image file in Drive to use for the background image. */
                id?: string;
                /**
                 * The width of the cropped image in the closed range of 0 to 1. This value represents the width of the cropped image divided by the width of the entire image. The height is
                 * computed by applying a width to height aspect ratio of 80 to 9. The resulting image must be at least 1280 pixels wide and 144 pixels high.
                 */
                width?: number;
                /**
                 * The X coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the horizontal
                 * distance from the left side of the entire image to the left side of the cropping area divided by the width of the entire image.
                 */
                xCoordinate?: number;
                /**
                 * The Y coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the vertical
                 * distance from the top side of the entire image to the top side of the cropping area divided by the height of the entire image.
                 */
                yCoordinate?: number;
            };
            /** A short-lived link to this Team Drive's background image. */
            backgroundImageLink?: string;
            /** Capabilities the current user has on this Team Drive. */
            capabilities?: {
                /** Whether the current user can add children to folders in this Team Drive. */
                canAddChildren?: boolean;
                /** Whether the current user can change the copyRequiresWriterPermission restriction of this Team Drive. */
                canChangeCopyRequiresWriterPermissionRestriction?: boolean;
                /** Whether the current user can change the domainUsersOnly restriction of this Team Drive. */
                canChangeDomainUsersOnlyRestriction?: boolean;
                /** Whether the current user can change the background of this Team Drive. */
                canChangeTeamDriveBackground?: boolean;
                /** Whether the current user can change the teamMembersOnly restriction of this Team Drive. */
                canChangeTeamMembersOnlyRestriction?: boolean;
                /** Whether the current user can comment on files in this Team Drive. */
                canComment?: boolean;
                /** Whether the current user can copy files in this Team Drive. */
                canCopy?: boolean;
                /** Whether the current user can delete children from folders in this Team Drive. */
                canDeleteChildren?: boolean;
                /** Whether the current user can delete this Team Drive. Attempting to delete the Team Drive may still fail if there are untrashed items inside the Team Drive. */
                canDeleteTeamDrive?: boolean;
                /** Whether the current user can download files in this Team Drive. */
                canDownload?: boolean;
                /** Whether the current user can edit files in this Team Drive */
                canEdit?: boolean;
                /** Whether the current user can list the children of folders in this Team Drive. */
                canListChildren?: boolean;
                /** Whether the current user can add members to this Team Drive or remove them or change their role. */
                canManageMembers?: boolean;
                /** Whether the current user can read the revisions resource of files in this Team Drive. */
                canReadRevisions?: boolean;
                /** Deprecated - use canDeleteChildren or canTrashChildren instead. */
                canRemoveChildren?: boolean;
                /** Whether the current user can rename files or folders in this Team Drive. */
                canRename?: boolean;
                /** Whether the current user can rename this Team Drive. */
                canRenameTeamDrive?: boolean;
                /** Whether the current user can share files or folders in this Team Drive. */
                canShare?: boolean;
                /** Whether the current user can trash children from folders in this Team Drive. */
                canTrashChildren?: boolean;
            };
            /** The color of this Team Drive as an RGB hex string. It can only be set on a drive.teamdrives.update request that does not set themeId. */
            colorRgb?: string;
            /** The time at which the Team Drive was created (RFC 3339 date-time). */
            createdTime?: string;
            /** The ID of this Team Drive which is also the ID of the top level folder of this Team Drive. */
            id?: string;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#teamDrive". */
            kind?: string;
            /** The name of this Team Drive. */
            name?: string;
            /** A set of restrictions that apply to this Team Drive or items inside this Team Drive. */
            restrictions?: {
                /** Whether administrative privileges on this Team Drive are required to modify restrictions. */
                adminManagedRestrictions?: boolean;
                /**
                 * Whether the options to copy, print, or download files inside this Team Drive, should be disabled for readers and commenters. When this restriction is set to true, it will
                 * override the similarly named field to true for any file inside this Team Drive.
                 */
                copyRequiresWriterPermission?: boolean;
                /**
                 * Whether access to this Team Drive and items inside this Team Drive is restricted to users of the domain to which this Team Drive belongs. This restriction may be overridden by
                 * other sharing policies controlled outside of this Team Drive.
                 */
                domainUsersOnly?: boolean;
                /** Whether access to items inside this Team Drive is restricted to members of this Team Drive. */
                teamMembersOnly?: boolean;
            };
            /**
             * The ID of the theme from which the background image and color will be set. The set of possible teamDriveThemes can be retrieved from a drive.about.get response. When not specified
             * on a drive.teamdrives.create request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that
             * don't set colorRgb or backgroundImageFile.
             */
            themeId?: string;
        }
        interface TeamDriveList {
            /** Identifies what kind of resource this is. Value: the fixed string "drive#teamDriveList". */
            kind?: string;
            /**
             * The page token for the next page of Team Drives. This will be absent if the end of the Team Drives list has been reached. If the token is rejected for any reason, it should be
             * discarded, and pagination should be restarted from the first page of results.
             */
            nextPageToken?: string;
            /** The list of Team Drives. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. */
            teamDrives?: TeamDrive[];
        }
        interface User {
            /** A plain text displayable name for this user. */
            displayName?: string;
            /** The email address of the user. This may not be present in certain contexts if the user has not made their email address visible to the requester. */
            emailAddress?: string;
            /** Identifies what kind of resource this is. Value: the fixed string "drive#user". */
            kind?: string;
            /** Whether this user is the requesting user. */
            me?: boolean;
            /** The user's ID as visible in Permission resources. */
            permissionId?: string;
            /** A link to the user's profile photo, if available. */
            photoLink?: string;
        }
        interface AboutResource {
            /** Gets information about the user, the user's Drive, and system capabilities. */
            get(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<About>;
        }
        interface ChangesResource {
            /** Gets the starting pageToken for listing future changes. */
            getStartPageToken(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the shared drive for which the starting pageToken for listing future changes from that shared drive is returned. */
                driveId?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated use driveId instead. */
                teamDriveId?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<StartPageToken>;
            /** Lists the changes for a user or shared drive. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The shared drive from which changes are returned. If specified the change IDs will be reflective of the shared drive; use the combined drive ID and change ID as an identifier. */
                driveId?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /**
                 * Whether changes should include the file resource if the file is still accessible by the user at the time of the request, even when a file was removed from the list of changes
                 * and there will be no further change entries for this file.
                 */
                includeCorpusRemovals?: boolean;
                /** Whether both My Drive and shared drive items should be included in results. */
                includeItemsFromAllDrives?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** Whether to include changes indicating that items have been removed from the list of changes, for example by deletion or loss of access. */
                includeRemoved?: boolean;
                /** Deprecated use includeItemsFromAllDrives instead. */
                includeTeamDriveItems?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The maximum number of changes to return per page. */
                pageSize?: number;
                /**
                 * The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response or to the response from the
                 * getStartPageToken method.
                 */
                pageToken: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Whether to restrict the results to changes inside the My Drive hierarchy. This omits changes to files such as those in the Application Data folder or shared files which have not
                 * been added to My Drive.
                 */
                restrictToMyDrive?: boolean;
                /** A comma-separated list of spaces to query within the user corpus. Supported values are 'drive', 'appDataFolder' and 'photos'. */
                spaces?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated use driveId instead. */
                teamDriveId?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<ChangeList>;
            /** Subscribes to changes for a user. */
            watch(request: {
                /** Data format for the response. */
                alt?: string;
                /** The shared drive from which changes are returned. If specified the change IDs will be reflective of the shared drive; use the combined drive ID and change ID as an identifier. */
                driveId?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /**
                 * Whether changes should include the file resource if the file is still accessible by the user at the time of the request, even when a file was removed from the list of changes
                 * and there will be no further change entries for this file.
                 */
                includeCorpusRemovals?: boolean;
                /** Whether both My Drive and shared drive items should be included in results. */
                includeItemsFromAllDrives?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** Whether to include changes indicating that items have been removed from the list of changes, for example by deletion or loss of access. */
                includeRemoved?: boolean;
                /** Deprecated use includeItemsFromAllDrives instead. */
                includeTeamDriveItems?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The maximum number of changes to return per page. */
                pageSize?: number;
                /**
                 * The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response or to the response from the
                 * getStartPageToken method.
                 */
                pageToken: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Whether to restrict the results to changes inside the My Drive hierarchy. This omits changes to files such as those in the Application Data folder or shared files which have not
                 * been added to My Drive.
                 */
                restrictToMyDrive?: boolean;
                /** A comma-separated list of spaces to query within the user corpus. Supported values are 'drive', 'appDataFolder' and 'photos'. */
                spaces?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated use driveId instead. */
                teamDriveId?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Channel;
            }): Request<Channel>;
            watch(request: {
                /** Data format for the response. */
                alt?: string;
                /** The shared drive from which changes are returned. If specified the change IDs will be reflective of the shared drive; use the combined drive ID and change ID as an identifier. */
                driveId?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /**
                 * Whether changes should include the file resource if the file is still accessible by the user at the time of the request, even when a file was removed from the list of changes
                 * and there will be no further change entries for this file.
                 */
                includeCorpusRemovals?: boolean;
                /** Whether both My Drive and shared drive items should be included in results. */
                includeItemsFromAllDrives?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** Whether to include changes indicating that items have been removed from the list of changes, for example by deletion or loss of access. */
                includeRemoved?: boolean;
                /** Deprecated use includeItemsFromAllDrives instead. */
                includeTeamDriveItems?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The maximum number of changes to return per page. */
                pageSize?: number;
                /**
                 * The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response or to the response from the
                 * getStartPageToken method.
                 */
                pageToken: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Whether to restrict the results to changes inside the My Drive hierarchy. This omits changes to files such as those in the Application Data folder or shared files which have not
                 * been added to My Drive.
                 */
                restrictToMyDrive?: boolean;
                /** A comma-separated list of spaces to query within the user corpus. Supported values are 'drive', 'appDataFolder' and 'photos'. */
                spaces?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated use driveId instead. */
                teamDriveId?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Channel): Request<Channel>;
        }
        interface ChannelsResource {
            /** Stop watching resources through this channel */
            stop(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Channel;
            }): Request<void>;
            stop(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Channel): Request<void>;
        }
        interface CommentsResource {
            /** Creates a new comment on a file. */
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Comment;
            }): Request<Comment>;
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Comment): Request<Comment>;
            /** Deletes a comment. */
            delete(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Gets a comment by ID. */
            get(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Whether to return deleted comments. Deleted comments will not include their original content. */
                includeDeleted?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<Comment>;
            /** Lists a file's comments. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Whether to include deleted comments. Deleted comments will not include their original content. */
                includeDeleted?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The maximum number of comments to return per page. */
                pageSize?: number;
                /** The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response. */
                pageToken?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The minimum value of 'modifiedTime' for the result comments (RFC 3339 date-time). */
                startModifiedTime?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<CommentList>;
            /** Updates a comment with patch semantics. */
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Comment;
            }): Request<Comment>;
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Comment): Request<Comment>;
        }
        interface DrivesResource {
            /** Creates a new shared drive. */
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * An ID, such as a random UUID, which uniquely identifies this user's request for idempotent creation of a shared drive. A repeated request by the same user and with the same
                 * request ID will avoid creating duplicates by attempting to create the same shared drive. If the shared drive already exists a 409 error will be returned.
                 */
                requestId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Drive;
            }): Request<Drive>;
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * An ID, such as a random UUID, which uniquely identifies this user's request for idempotent creation of a shared drive. A repeated request by the same user and with the same
                 * request ID will avoid creating duplicates by attempting to create the same shared drive. If the shared drive already exists a 409 error will be returned.
                 */
                requestId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Drive): Request<Drive>;
            /** Permanently deletes a shared drive for which the user is an organizer. The shared drive cannot contain any untrashed items. */
            delete(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the shared drive. */
                driveId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Gets a shared drive's metadata by ID. */
            get(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the shared drive. */
                driveId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the shared drive
                 * belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<Drive>;
            /** Hides a shared drive from the default view. */
            hide(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the shared drive. */
                driveId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<Drive>;
            /** Lists the user's shared drives. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Maximum number of shared drives to return. */
                pageSize?: number;
                /** Page token for shared drives. */
                pageToken?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** Query string for searching shared drives. */
                q?: string;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Issue the request as a domain administrator; if set to true, then all shared drives of the domain in which the requester is an administrator are returned. */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<DriveList>;
            /** Restores a shared drive to the default view. */
            unhide(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the shared drive. */
                driveId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<Drive>;
            /** Updates the metadate for a shared drive. */
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the shared drive. */
                driveId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the shared drive
                 * belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Drive;
            }): Request<Drive>;
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the shared drive. */
                driveId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the shared drive
                 * belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Drive): Request<Drive>;
        }
        interface FilesResource {
            /** Creates a copy of a file and applies any requested updates with patch semantics. Folders cannot be copied. */
            copy(request: {
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. Requests that
                 * specify more than one parent fail.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /**
                 * Whether to ignore the domain's default visibility settings for the created file. Domain administrators can choose to make all uploaded files visible to the domain by default;
                 * this parameter bypasses that behavior for the request. Permissions are still inherited from parent folders.
                 */
                ignoreDefaultVisibility?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /**
                 * Whether to set the 'keepForever' field in the new head revision. This is only applicable to files with binary content in Google Drive. Only 200 revisions for the file can be
                 * kept forever. If the limit is reached, try deleting pinned revisions.
                 */
                keepRevisionForever?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** A language hint for OCR processing during image import (ISO 639-1 code). */
                ocrLanguage?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: File;
            }): Request<File>;
            copy(request: {
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. Requests that
                 * specify more than one parent fail.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /**
                 * Whether to ignore the domain's default visibility settings for the created file. Domain administrators can choose to make all uploaded files visible to the domain by default;
                 * this parameter bypasses that behavior for the request. Permissions are still inherited from parent folders.
                 */
                ignoreDefaultVisibility?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /**
                 * Whether to set the 'keepForever' field in the new head revision. This is only applicable to files with binary content in Google Drive. Only 200 revisions for the file can be
                 * kept forever. If the limit is reached, try deleting pinned revisions.
                 */
                keepRevisionForever?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** A language hint for OCR processing during image import (ISO 639-1 code). */
                ocrLanguage?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: File): Request<File>;
            /** Creates a new file. */
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. Requests that
                 * specify more than one parent fail.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /**
                 * Whether to ignore the domain's default visibility settings for the created file. Domain administrators can choose to make all uploaded files visible to the domain by default;
                 * this parameter bypasses that behavior for the request. Permissions are still inherited from parent folders.
                 */
                ignoreDefaultVisibility?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /**
                 * Whether to set the 'keepForever' field in the new head revision. This is only applicable to files with binary content in Google Drive. Only 200 revisions for the file can be
                 * kept forever. If the limit is reached, try deleting pinned revisions.
                 */
                keepRevisionForever?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** A language hint for OCR processing during image import (ISO 639-1 code). */
                ocrLanguage?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to use the uploaded content as indexable text. */
                useContentAsIndexableText?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: File;
            }): Request<File>;
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. Requests that
                 * specify more than one parent fail.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /**
                 * Whether to ignore the domain's default visibility settings for the created file. Domain administrators can choose to make all uploaded files visible to the domain by default;
                 * this parameter bypasses that behavior for the request. Permissions are still inherited from parent folders.
                 */
                ignoreDefaultVisibility?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /**
                 * Whether to set the 'keepForever' field in the new head revision. This is only applicable to files with binary content in Google Drive. Only 200 revisions for the file can be
                 * kept forever. If the limit is reached, try deleting pinned revisions.
                 */
                keepRevisionForever?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** A language hint for OCR processing during image import (ISO 639-1 code). */
                ocrLanguage?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to use the uploaded content as indexable text. */
                useContentAsIndexableText?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: File): Request<File>;
            /**
             * Permanently deletes a file owned by the user without moving it to the trash. If the file belongs to a shared drive the user must be an organizer on the parent. If the target is a
             * folder, all descendants owned by the user are also deleted.
             */
            delete(request?: {
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter will only take effect if the item is not in a shared drive. If an item's
                 * last parent is deleted but the item itself is not, the item will be placed under its owner's root.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Permanently deletes all of the user's trashed files. */
            emptyTrash(request?: {
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter will only take effect if the item is not in a shared drive. If an item's
                 * last parent is deleted but the item itself is not, the item will be placed under its owner's root.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Exports a Google Doc to the requested MIME type and returns the exported content. Please note that the exported content is limited to 10MB. */
            export(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** The MIME type of the format requested for this export. */
                mimeType: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Generates a set of file IDs which can be provided in create or copy requests. */
            generateIds(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The number of IDs to return. */
                count?: number;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The space in which the IDs can be used to create new files. Supported values are 'drive' and 'appDataFolder'. */
                space?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<GeneratedIds>;
            /** Gets a file's metadata or content by ID. */
            get(request?: {
                /** Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when alt=media. */
                acknowledgeAbuse?: boolean;
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<File>;
            /** Lists or searches files. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /**
                 * Groupings of files to which the query applies. Supported groupings are: 'user' (files created by, opened by, or shared directly with the user), 'drive' (files in the specified
                 * shared drive as indicated by the 'driveId'), 'domain' (files shared to the user's domain), and 'allDrives' (A combination of 'user' and 'drive' for all drives where the user is
                 * a member). When able, use 'user' or 'drive', instead of 'allDrives', for efficiency.
                 */
                corpora?: string;
                /** The source of files to list. Deprecated: use 'corpora' instead. */
                corpus?: string;
                /** ID of the shared drive to search. */
                driveId?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** Whether both My Drive and shared drive items should be included in results. */
                includeItemsFromAllDrives?: boolean;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** Deprecated use includeItemsFromAllDrives instead. */
                includeTeamDriveItems?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /**
                 * A comma-separated list of sort keys. Valid keys are 'createdTime', 'folder', 'modifiedByMeTime', 'modifiedTime', 'name', 'name_natural', 'quotaBytesUsed', 'recency',
                 * 'sharedWithMeTime', 'starred', and 'viewedByMeTime'. Each key sorts ascending by default, but may be reversed with the 'desc' modifier. Example usage:
                 * ?orderBy=folder,modifiedTime desc,name. Please note that there is a current limitation for users with approximately one million files in which the requested sort order is
                 * ignored.
                 */
                orderBy?: string;
                /** The maximum number of files to return per page. Partial or empty result pages are possible even before the end of the files list has been reached. */
                pageSize?: number;
                /** The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response. */
                pageToken?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** A query for filtering the file results. See the "Search for Files" guide for supported syntax. */
                q?: string;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** A comma-separated list of spaces to query within the corpus. Supported values are 'drive', 'appDataFolder' and 'photos'. */
                spaces?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated use driveId instead. */
                teamDriveId?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<FileList>;
            /** Updates a file's metadata and/or content. This method supports patch semantics. */
            update(request: {
                /** A comma-separated list of parent IDs to add. */
                addParents?: string;
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. If the item's
                 * owner makes a request to add a single parent, the item is removed from all current folders and placed in the requested folder. Other requests that increase the number of parents
                 * fail, except when the canAddMyDriveParent file capability is true and a single parent is being added.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /**
                 * Whether to set the 'keepForever' field in the new head revision. This is only applicable to files with binary content in Google Drive. Only 200 revisions for the file can be
                 * kept forever. If the limit is reached, try deleting pinned revisions.
                 */
                keepRevisionForever?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** A language hint for OCR processing during image import (ISO 639-1 code). */
                ocrLanguage?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** A comma-separated list of parent IDs to remove. */
                removeParents?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to use the uploaded content as indexable text. */
                useContentAsIndexableText?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: File;
            }): Request<File>;
            update(request: {
                /** A comma-separated list of parent IDs to add. */
                addParents?: string;
                /** Data format for the response. */
                alt?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. If the item's
                 * owner makes a request to add a single parent, the item is removed from all current folders and placed in the requested folder. Other requests that increase the number of parents
                 * fail, except when the canAddMyDriveParent file capability is true and a single parent is being added.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /**
                 * Whether to set the 'keepForever' field in the new head revision. This is only applicable to files with binary content in Google Drive. Only 200 revisions for the file can be
                 * kept forever. If the limit is reached, try deleting pinned revisions.
                 */
                keepRevisionForever?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** A language hint for OCR processing during image import (ISO 639-1 code). */
                ocrLanguage?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** A comma-separated list of parent IDs to remove. */
                removeParents?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to use the uploaded content as indexable text. */
                useContentAsIndexableText?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: File): Request<File>;
            /** Subscribes to changes to a file */
            watch(request: {
                /** Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when alt=media. */
                acknowledgeAbuse?: boolean;
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Channel;
            }): Request<Channel>;
            watch(request: {
                /** Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when alt=media. */
                acknowledgeAbuse?: boolean;
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Channel): Request<Channel>;
        }
        interface PermissionsResource {
            /** Creates a permission for a file or shared drive. */
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** A plain text custom message to include in the notification email. */
                emailMessage?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. See
                 * moveToNewOwnersRoot for details.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file or shared drive. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /**
                 * This parameter only takes effect if the item is not in a shared drive and the request is attempting to transfer the ownership of the item. When set to true, the item is moved to
                 * the new owner's My Drive root folder and all prior parents removed. If set to false, when enforceSingleParent=true, parents are not changed. If set to false, when
                 * enforceSingleParent=false, existing parents are not changed; however, the file will be added to the new owner's My Drive root folder, unless it is already in the new owner's My
                 * Drive.
                 */
                moveToNewOwnersRoot?: boolean;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Whether to send a notification email when sharing to users or groups. This defaults to true for users and groups, and is not allowed for other requests. It must not be disabled
                 * for ownership transfers.
                 */
                sendNotificationEmail?: boolean;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to transfer ownership to the specified user and downgrade the current owner to a writer. This parameter is required as an acknowledgement of the side effect. */
                transferOwnership?: boolean;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an
                 * administrator of the domain to which the shared drive belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Permission;
            }): Request<Permission>;
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** A plain text custom message to include in the notification email. */
                emailMessage?: string;
                /**
                 * Set to true to opt in to API behavior that aims for all items to have exactly one parent. This parameter only takes effect if the item is not in a shared drive. See
                 * moveToNewOwnersRoot for details.
                 */
                enforceSingleParent?: boolean;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file or shared drive. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /**
                 * This parameter only takes effect if the item is not in a shared drive and the request is attempting to transfer the ownership of the item. When set to true, the item is moved to
                 * the new owner's My Drive root folder and all prior parents removed. If set to false, when enforceSingleParent=true, parents are not changed. If set to false, when
                 * enforceSingleParent=false, existing parents are not changed; however, the file will be added to the new owner's My Drive root folder, unless it is already in the new owner's My
                 * Drive.
                 */
                moveToNewOwnersRoot?: boolean;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * Whether to send a notification email when sharing to users or groups. This defaults to true for users and groups, and is not allowed for other requests. It must not be disabled
                 * for ownership transfers.
                 */
                sendNotificationEmail?: boolean;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to transfer ownership to the specified user and downgrade the current owner to a writer. This parameter is required as an acknowledgement of the side effect. */
                transferOwnership?: boolean;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an
                 * administrator of the domain to which the shared drive belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Permission): Request<Permission>;
            /** Deletes a permission. */
            delete(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file or shared drive. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The ID of the permission. */
                permissionId: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an
                 * administrator of the domain to which the shared drive belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Gets a permission by ID. */
            get(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The ID of the permission. */
                permissionId: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an
                 * administrator of the domain to which the shared drive belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<Permission>;
            /** Lists a file's or shared drive's permissions. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file or shared drive. */
                fileId: string;
                /** Specifies which additional view's permissions to include in the response. Only 'published' is supported. */
                includePermissionsForView?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /**
                 * The maximum number of permissions to return per page. When not set for files in a shared drive, at most 100 results will be returned. When not set for files that are not in a
                 * shared drive, the entire list will be returned.
                 */
                pageSize?: number;
                /** The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response. */
                pageToken?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an
                 * administrator of the domain to which the shared drive belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<PermissionList>;
            /** Updates a permission with patch semantics. */
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file or shared drive. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The ID of the permission. */
                permissionId: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether to remove the expiration date. */
                removeExpiration?: boolean;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to transfer ownership to the specified user and downgrade the current owner to a writer. This parameter is required as an acknowledgement of the side effect. */
                transferOwnership?: boolean;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an
                 * administrator of the domain to which the shared drive belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Permission;
            }): Request<Permission>;
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file or shared drive. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The ID of the permission. */
                permissionId: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Whether to remove the expiration date. */
                removeExpiration?: boolean;
                /** Whether the requesting application supports both My Drives and shared drives. */
                supportsAllDrives?: boolean;
                /** Deprecated use supportsAllDrives instead. */
                supportsTeamDrives?: boolean;
                /** Whether to transfer ownership to the specified user and downgrade the current owner to a writer. This parameter is required as an acknowledgement of the side effect. */
                transferOwnership?: boolean;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an
                 * administrator of the domain to which the shared drive belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Permission): Request<Permission>;
        }
        interface RepliesResource {
            /** Creates a new reply to a comment. */
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Reply;
            }): Request<Reply>;
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Reply): Request<Reply>;
            /** Deletes a reply. */
            delete(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the reply. */
                replyId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Gets a reply by ID. */
            get(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Whether to return deleted replies. Deleted replies will not include their original content. */
                includeDeleted?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the reply. */
                replyId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<Reply>;
            /** Lists a comment's replies. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** Whether to include deleted replies. Deleted replies will not include their original content. */
                includeDeleted?: boolean;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The maximum number of replies to return per page. */
                pageSize?: number;
                /** The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response. */
                pageToken?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<ReplyList>;
            /** Updates a reply with patch semantics. */
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the reply. */
                replyId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Reply;
            }): Request<Reply>;
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** The ID of the comment. */
                commentId: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the reply. */
                replyId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Reply): Request<Reply>;
        }
        interface RevisionsResource {
            /**
             * Permanently deletes a file version. You can only delete revisions for files with binary content in Google Drive, like images or videos. Revisions for other files, like Google Docs
             * or Sheets, and the last remaining file version can't be deleted.
             */
            delete(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the revision. */
                revisionId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Gets a revision's metadata or content by ID. */
            get(request?: {
                /** Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when alt=media. */
                acknowledgeAbuse?: boolean;
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the revision. */
                revisionId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<Revision>;
            /** Lists a file's revisions. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** The maximum number of revisions to return per page. */
                pageSize?: number;
                /** The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response. */
                pageToken?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<RevisionList>;
            /** Updates a revision with patch semantics. */
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the revision. */
                revisionId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: Revision;
            }): Request<Revision>;
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** The ID of the file. */
                fileId: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the revision. */
                revisionId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: Revision): Request<Revision>;
        }
        interface TeamdrivesResource {
            /** Deprecated use drives.create instead. */
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * An ID, such as a random UUID, which uniquely identifies this user's request for idempotent creation of a Team Drive. A repeated request by the same user and with the same
                 * request ID will avoid creating duplicates by attempting to create the same Team Drive. If the Team Drive already exists a 409 error will be returned.
                 */
                requestId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: TeamDrive;
            }): Request<TeamDrive>;
            create(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /**
                 * An ID, such as a random UUID, which uniquely identifies this user's request for idempotent creation of a Team Drive. A repeated request by the same user and with the same
                 * request ID will avoid creating duplicates by attempting to create the same Team Drive. If the Team Drive already exists a 409 error will be returned.
                 */
                requestId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: TeamDrive): Request<TeamDrive>;
            /** Deprecated use drives.delete instead. */
            delete(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the Team Drive */
                teamDriveId: string;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<void>;
            /** Deprecated use drives.get instead. */
            get(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the Team Drive */
                teamDriveId: string;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the Team Drive
                 * belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<TeamDrive>;
            /** Deprecated use drives.list instead. */
            list(request?: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Maximum number of Team Drives to return. */
                pageSize?: number;
                /** Page token for Team Drives. */
                pageToken?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** Query string for searching Team Drives. */
                q?: string;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** Issue the request as a domain administrator; if set to true, then all Team Drives of the domain in which the requester is an administrator are returned. */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            }): Request<TeamDriveList>;
            /** Deprecated use drives.update instead */
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the Team Drive */
                teamDriveId: string;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the Team Drive
                 * belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
                /** Request body */
                resource: TeamDrive;
            }): Request<TeamDrive>;
            update(request: {
                /** Data format for the response. */
                alt?: string;
                /** Selector specifying which fields to include in a partial response. */
                fields?: string;
                /** API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. */
                key?: string;
                /** OAuth 2.0 token for the current user. */
                oauth_token?: string;
                /** Returns response with indentations and line breaks. */
                prettyPrint?: boolean;
                /** An opaque string that represents a user for quota purposes. Must not exceed 40 characters. */
                quotaUser?: string;
                /** The ID of the Team Drive */
                teamDriveId: string;
                /**
                 * Issue the request as a domain administrator; if set to true, then the requester will be granted access if they are an administrator of the domain to which the Team Drive
                 * belongs.
                 */
                useDomainAdminAccess?: boolean;
                /** Deprecated. Please use quotaUser instead. */
                userIp?: string;
            },
            body: TeamDrive): Request<TeamDrive>;
        }

        const about: AboutResource;

        const changes: ChangesResource;

        const channels: ChannelsResource;

        const comments: CommentsResource;

        const drives: DrivesResource;

        const files: FilesResource;

        const permissions: PermissionsResource;

        const replies: RepliesResource;

        const revisions: RevisionsResource;

        const teamdrives: TeamdrivesResource;
    }
}
